@@ -1,6 +1,7 @@
 from datetime import datetime
 import time
 from plyer import notification
+from importlib.abc import ResourceReader as res
 import pkgutil
 
 
@@ -12,7 +13,7 @@ def notifier_weekday(weekend_mess):
     notification.notify(
         title=weekend_mess,
         message="Have a good day",
-        app_icon=pkgutil.get_data('notifier', 'sea_fishes.ico'),
+        app_icon= res.resource_path('.', 'sea_fishes.ico'),
         timeout=60
     )
 
